@@ -2,14 +2,14 @@ package Yars::Command::yars_disk_scan;
 
 # PODNAME: yars_disk_scan
 # ABSTRACT: scan a disk for corruption and report corrupt files to stdout
-our $VERSION = '1.25'; # VERSION
+our $VERSION = '1.26'; # VERSION
 
 
 use strict;
 use warnings;
 use 5.010;
 use Clustericious::Config;
-use Log::Log4perl::CommandLine qw/:all/;
+use Clustericious::Log::CommandLine qw/:all/;
 use Clustericious::Log;
 use File::Find::Rule;
 use Digest::file qw/digest_file_hex/;
