@@ -2,7 +2,7 @@ package Yars::Command::yars_fast_balance;
 
 # PODNAME: yars_fast_balance
 # ABSTRACT: Fix all files
-our $VERSION = '1.25'; # VERSION
+our $VERSION = '1.26'; # VERSION
 
 
 use strict;
@@ -10,7 +10,7 @@ use warnings;
 use 5.010;
 use Yars::Client;
 use Log::Log4perl ();
-use Log::Log4perl::CommandLine ':all', ':loginit' => { level => $Log::Log4perl::INFO };
+use Clustericious::Log::CommandLine ':all', ':loginit' => { level => $Log::Log4perl::INFO };
 use Clustericious::Log;
 use Clustericious::Config;
 use Hash::MoreUtils qw/safe_reverse/;
